==> v1.0.13.tar.gz: element-android/vector/src/main/java/im/vector/app/features/home/room/detail/widget/RoomWidgetsBannerView.kt <==
/*
 * Copyright (c) 2020 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package im.vector.app.features.home.room.detail.widget

import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.widget.RelativeLayout
import im.vector.app.R
import kotlinx.android.synthetic.main.view_room_widgets_banner.view.*
import org.matrix.android.sdk.api.session.widgets.model.Widget

class RoomWidgetsBannerView @JvmOverloads constructor(
        context: Context,
        attrs: AttributeSet? = null,
        defStyleAttr: Int = 0
) : RelativeLayout(context, attrs, defStyleAttr) {

    interface Callback {
        fun onViewWidgetsClicked()
    }

    var callback: Callback? = null

    init {
        setupView()
    }

    private fun setupView() {
        inflate(context, R.layout.view_room_widgets_banner, this)
        setBackgroundResource(R.drawable.bg_active_widgets_banner)
        setOnClickListener {
            callback?.onViewWidgetsClicked()
        }
    }

    fun render(widgets: List<Widget>?) {
        if (widgets.isNullOrEmpty()) {
            visibility = View.GONE
        } else {
            visibility = View.VISIBLE
            activeWidgetsLabel.text = context.resources.getQuantityString(R.plurals.active_widgets, widgets.size, widgets.size)
        }
    }
}

==> v1.3.1.tar.gz: element-android/vector/src/main/java/im/vector/app/features/home/room/detail/widget/RoomWidgetsBannerView.kt <==
/*
 * Copyright (c) 2020 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package im.vector.app.features.home.room.detail.widget

import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.widget.RelativeLayout
import im.vector.app.R
import im.vector.app.databinding.ViewRoomWidgetsBannerBinding

import org.matrix.android.sdk.api.session.widgets.model.Widget

class RoomWidgetsBannerView @JvmOverloads constructor(
        context: Context,
        attrs: AttributeSet? = null,
        defStyleAttr: Int = 0
) : RelativeLayout(context, attrs, defStyleAttr) {

    interface Callback {
        fun onViewWidgetsClicked()
    }

    private val views: ViewRoomWidgetsBannerBinding

    var callback: Callback? = null

    init {
        setupView()
        views = ViewRoomWidgetsBannerBinding.bind(this)
    }

    private fun setupView() {
        inflate(context, R.layout.view_room_widgets_banner, this)
        setBackgroundResource(R.drawable.bg_active_widgets_banner)
        setOnClickListener {
            callback?.onViewWidgetsClicked()
        }
    }

    fun render(widgets: List<Widget>?) {
        if (widgets.isNullOrEmpty()) {
            visibility = View.GONE
        } else {
            visibility = View.VISIBLE
            views.activeWidgetsLabel.text = context.resources.getQuantityString(R.plurals.active_widgets, widgets.size, widgets.size)
        }
    }
}
